@@ -1,9 +1,5 @@
 "UPtille" <-
-function(pik,eps=0.000005)
-##########################################
-# select an unequal probability sample by means of 
-# the tille method.
-##########################################
+function(pik,eps=1e-6)
 {
 liste= pik>eps & pik < 1-eps
 pikb=pik[liste]
